==> libreoffice-l10n_4.4.6~rc3.orig.tar.xz: libreoffice-4.4.6~rc3/reportdesign/source/core/sdr/RptObjectListener.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */
#include "RptObjectListener.hxx"
#include "RptObject.hxx"
#include "RptDef.hxx"

namespace rptui
{

// OObjectListener



OObjectListener::OObjectListener(OObjectBase* _pObject)
          :m_pObject(_pObject)
{
}



OObjectListener::~OObjectListener()
{
}

// XEventListener


void SAL_CALL OObjectListener::disposing( const  ::com::sun::star::lang::EventObject& ) throw( ::com::sun::star::uno::RuntimeException, std::exception)
{
}

// XPropertyChangeListener


void SAL_CALL OObjectListener::propertyChange( const  ::com::sun::star::beans::PropertyChangeEvent& evt ) throw( ::com::sun::star::uno::RuntimeException, std::exception)
{
    m_pObject->_propertyChange( evt );
}




// DlgEdHint


DlgEdHint::DlgEdHint(DlgEdHintKind eHint)
    : eHintKind(eHint)
    , pDlgEdObj(NULL)
{
}


DlgEdHint::~DlgEdHint()
{
}

}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice-l10n_5.1.2.orig.tar.xz: libreoffice-5.1.2/reportdesign/source/core/sdr/RptObjectListener.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */
#include "RptObjectListener.hxx"
#include "RptObject.hxx"
#include "RptDef.hxx"

namespace rptui
{

// OObjectListener



OObjectListener::OObjectListener(OObjectBase* _pObject)
          :m_pObject(_pObject)
{
}



OObjectListener::~OObjectListener()
{
}

// XEventListener


void SAL_CALL OObjectListener::disposing( const  css::lang::EventObject& ) throw( css::uno::RuntimeException, std::exception)
{
}

// XPropertyChangeListener


void SAL_CALL OObjectListener::propertyChange( const  css::beans::PropertyChangeEvent& evt ) throw( css::uno::RuntimeException, std::exception)
{
    m_pObject->_propertyChange( evt );
}




// DlgEdHint


DlgEdHint::DlgEdHint(DlgEdHintKind eHint)
    : eHintKind(eHint)
{
}


DlgEdHint::~DlgEdHint()
{
}

}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
